Name:			diffuse
Version:		0.6.0
Release:		1%{?dist}
Summary:		Graphical tool for merging and comparing text files
License:		GPLv2+
URL:			https://mightycreak.github.io/diffuse/
Source0:		https://codeload.github.com/MightyCreak/diffuse/tar.gz/v%{version}
BuildArch:		noarch
BuildRequires:		desktop-file-utils
BuildRequires:		gettext
BuildRequires:		autoconf
BuildRequires:		meson
BuildRequires:		python3-devel
BuildRequires:		python3-gobject
BuildRequires:		python3-cairo
BuildRequires:		gtk-update-icon-cache
Requires:		hicolor-icon-theme
Provides:		mergetool
Provides:		difftool

%description
Diffuse is a graphical tool for merging and comparing text files. Diffuse is
able to compare an arbitrary number of files side-by-side and gives users the
ability to manually adjust line-matching and directly edit files. Diffuse can
also retrieve revisions of files from Bazaar, CVS, Darcs, Git, Mercurial,
Monotone, RCS, Subversion, and SVK repositories for comparison and merging.
This is the Python 3 fork of Diffuse.

%prep
%autosetup

%build
%meson

%install
%meson_install
#
# Register as an application to be visible in the software center
#
# NOTE: It would be *awesome* if this file was maintained by the upstream
# project, translated and installed into the right place during `make install`.
#
# See http://www.freedesktop.org/software/appstream/docs/ for more details.
#
mkdir -p %{buildroot}%{_datadir}/metainfo
cat > %{buildroot}%{_datadir}/metainfo/%{name}.appdata.xml <<EOF
<?xml version="1.0" encoding="UTF-8"?>
<component type="desktop-application">
  <id>io.github.mightycreak.Diffuse</id>

  <name>Diffuse Merge Tool</name>
  <summary>Graphical tool for merging and comparing text files</summary>
  <description>
    <p>
      Diffuse is a graphical tool for comparing and merging text files. It can retrieve files for comparison from Bazaar, CVS, Darcs, Git, Mercurial, Monotone, RCS, Subversion, and SVK repositories.
    </p>
  </description>

  <metadata_license>FSFAP</metadata_license>
  <project_license>GPL-2.0-or-later</project_license>
  <content_rating type="oars-1.1" />

  <launchable type="desktop-id">io.github.mightycreak.Diffuse.desktop</launchable>

  <url type="homepage">https://mightycreak.github.io/diffuse/</url>
  <url type="bugtracker">https://github.com/MightyCreak/diffuse/issues</url>

  <screenshots>
    <screenshot type="default">
      <image>https://mightycreak.github.io/diffuse/images/screenshot_v0.5.0.png</image>
      <caption>Main window: diff between two files</caption>
    </screenshot>
  </screenshots>

  <releases>
    <release version="0.6.0" date="2020-11-29">
      <description>
        <p>
          Mainly under the hood changes in this release, so nothing really visible to the users in this version. That
          said, I figured it was a long time since the last release (4 months ago) and, as promised, I want Diffuse
          development to be a bit more active and iterative.
        </p>
        <p>
          Apart from the maintenance changes, I think the main improvement is that Diffuse will soon be available
          through Flathub!
        </p>
        <p>Added:</p>
        <ul>
          <li>New Flatpak package, published on Flathub: com.github.mightycreak.Diffuse</li>
        </ul>
        <p>Changed:</p>
        <ul>
          <li>Replace old install.py with the more standard Meson</li>
          <li>Remove u string prefixes since Python 3 is in UTF-8 by default</li>
          <li>Replaced some interpolation operators (%) for the f string prefix</li>
          <li>Use the window scale factor for the icons generation</li>
        </ul>
      </description>
    </release>
    <release version="0.5.0" date="2020-07-18">
      <description>
        <p>
          Here is the v0.5.0. Unintentionally, this release happens exactly 6 years after the previous v0.4.8 release!
        </p>
        <p>
          There is a lot to do on this application, and some features didn't make the release. The main one being the
          Windows installers. I think 6 years is too long to continue to wait until this bug is fixed. The Python
          scripts should work on Windows, but no executable is produced (yet) with the release.
        </p>
        <p>
          Other than that, Diffuse v0.5.0 is now officially compatible with Python 3 and GTK 3! And it is synced to the
          latest commits from upstream (which were never released).
        </p>
        <p>
          The next version will not take 6 years, I promise you!
        </p>
        <p>Added:</p>
        <ul>
          <li>Added Pedro Albuquerque's Portuguese translation</li>
          <li>Added Ã…ke Engelbrektson's Swedish translation</li>
          <li>Added Guillaume Hoffmann's Darcs support improvements</li>
          <li>Added Akom Chotiphantawanon's Thai translation</li>
          <li>Added support for Git submodules</li>
          <li>Added a preference and command line option to specify the version control system search order</li>
          <li>Added .editorconfig file</li>
          <li>Added .gitignore file</li>
          <li>Added message when removing files during uninstallation</li>
          <li>Added Python script to update all the translation files at once</li>
        </ul>
        <p>Changed:</p>
        <ul>
          <li>Convert to Python 3</li>
          <li>Convert to GTK 3</li>
          <li>Updated Python highlighting for Python 3 grammar</li>
          <li>Updated copyrights years and authors</li>
          <li>Improve Spanish translation</li>
          <li>Convert translation README to MarkDown</li>
          <li>Updated all the translation files</li>
        </ul>
        <p>Fixed:</p>
        <ul>
          <li>Fixed wrong icons directory for gtk-update-icon-cache</li>
          <li>Fixed missing directories when uninstalling</li>
          <li>Fixed bug introduced by r420 with RCS VCS</li>
          <li>Fixed broken drag'n'drop since migration to Python3/GTK3</li>
          <li>Fixed error when using '-m' in an SVN repo</li>
        </ul>
      </description>
    </release>
  </releases>

  <developer_name>Romain Failliot</developer_name>
  <update_contact>romain.failliot@foolstep.com</update_contact>
</component>
EOF

%find_lang %{name}

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop
%meson_test

%files -f %{name}.lang
%license COPYING
%doc AUTHORS CHANGELOG.md README.md
%config(noreplace) %{_sysconfdir}/diffuserc
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/gnome/help/%{name}/*/%{name}.xml
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/omf/%{name}/%{name}-*.omf
%{_mandir}/man*/*
%{_mandir}/*/man*/*
%{_datadir}/omf/%{name}
%{_datadir}/gnome/help/%{name}

%changelog
* Wed May 26 2021 niohiani <notinsideofhereiamnotinside@gmail.com> 0.6.0-1
- Packaging of this application is now up to par for inclusion in the default repos. Upon successfully importing the package, the COPR repository for test builds will become defunct.

* Mon Dec  7 2020 niohiani <notinsideofhereiamnotinside@gmail.com> 0.6.0
- Updated to 0.6.0. Mainly under the hood changes in this release, so nothing really visible to the users in this version. That said, I figured it was a long time since the last release (4 months ago) and, as promised, I want Diffuse development to be a bit more active and iterative. Replace old install.py with the more standard Meson. Remove u string prefixes since Python 3 is in UTF-8 by default. Replaced some interpolation operators (%) for the f string prefix. Use the window scale factor for the icons generation

* Tue Nov  3 2020 niohiani <notinsideofhereiamnotinside@gmail.com> 0.5.9
- Fedora Packaging of Python 3 Fork and Initial upload to COPR of said fork